@@ -22,7 +22,7 @@
  +-------------------------------------------------------------------------+
 */
 
-/*
+/**
  * Make sure these values reflect your actual database/host/user/password
  */
 
@@ -39,7 +39,7 @@ $database_ssl_cert = '';
 $database_ssl_ca   = '';
 $database_persist  = false;
 
-/*
+/**
  * When the cacti server is a remote poller, then these entries point to
  * the main cacti server. Otherwise, these variables have no use and
  * must remain commented out.
@@ -57,14 +57,14 @@ $database_persist  = false;
 #$rdatabase_ssl_cert = '';
 #$rdatabase_ssl_ca   = '';
 
-/*
+/**
  * The poller_id of this system.  set to `1` for the main cacti web server.
  * Otherwise, you this value should be the poller_id for the remote poller.
  */
 
 $poller_id = 1;
 
-/*
+/**
  * Set the $url_path to point to the default URL of your cacti install.
  * For example if your cacti install as at `https://serverip/cacti/` this
  * would be set to `/cacti/`.
@@ -72,31 +72,31 @@ $poller_id = 1;
 
 $url_path = '/cacti/';
 
-/*
+/**
  * Default session name - session name must contain alpha characters
  */
 
 $cacti_session_name = 'Cacti';
 
-/*
+/**
  * Default Cookie domain - The cookie domain to be used for Cacti
  */
 
 //$cacti_cookie_domain = 'cacti.net';
 
-/*
+/**
  * Save sessions to a database for load balancing
  */
 
 $cacti_db_session = false;
 
-/*
+/**
  * Disable log rotation settings for packagers
  */
 
 $disable_log_rotation = false;
 
-/*
+/**
  * Optional parameters to define scripts and resource paths. These
  * variables become important when using remote poller installs when the
  * scripts and resource files are not in the main Cacti web server path.
@@ -105,7 +105,7 @@ $disable_log_rotation = false;
 //$scripts_path = '/var/www/html/cacti/scripts';
 //$resource_path = '/var/www/html/cacti/resource/';
 
-/*
+/**
  * Optional parameter to define a data input whitelist command string. This
  * whitelist file will help protect cacti from unauthorized changes to Cacti
  * data input command string.
@@ -113,19 +113,19 @@ $disable_log_rotation = false;
 
 //$input_whitelist = '/usr/local/etc/cacti/input_whitelist.json';
 
-/*
+/**
  * Optional parameter to give explicit path to PHP
  */
 //$php_path = '/bin/php';
 
-/*
+/**
  * Optional parameter to disable the PHP SNMP extension. If not set, defaults
  * to class_exists('SNMP').
  */
 
 //$php_snmp_support = false;
 
-/*
+/**
  * Optional parameter to define the path of the csrf_secret.php path.  This
  * variable is for packagers who wish to specify an alternate location of
  * the CRSF secret file.
@@ -133,7 +133,7 @@ $disable_log_rotation = false;
 
 //$path_csrf_secret = '/usr/share/cacti/resource/csrf-secret.php';
 
-/*
+/**
  * The following are optional variables for debugging low level system
  * functions that are generally only used by Cacti Developers to help
  * identify potential issues in commonly used functions
@@ -143,23 +143,57 @@ $disable_log_rotation = false;
  * ability to fine turn and turn them off.
  */
 
-/*
+/**
  * Debug the read_config_option program flow
  */
-# define('DEBUG_READ_CONFIG_OPTION', true);
+#if (!defined('DEBUG_READ_CONFIG_OPTION')) {
+#	define('DEBUG_READ_CONFIG_OPTION', true);
+#}
 
-/*
+/**
  * Automatically suppress the DEBUG_READ_CONFIG_OPTION
  */
-# define('DEBUG_READ_CONFIG_OPTION_DB_OPEN', true);
+#if (!defined('DEBUG_READ_CONFIG_OPTION_DB_OPEN')) {
+#	define('DEBUG_READ_CONFIG_OPTION_DB_OPEN', true);
+#}
 
-/*
+/**
  * Always write the SQL command to the cacti log file
  */
-# define('DEBUG_SQL_CMD', true);
+#if (!defined('DEBUG_SQL_CMD')) {
+#	define('DEBUG_SQL_CMD', true);
+#}
 
-/*
+/**
  * Debug the flow of calls to the db_xxx functions that
  * are defined in lib/database.php
  */
-# define('DEBUG_SQL_FLOW', true);
+#if (!defined('DEBUG_SQL_FLOW')) {
+#	define('DEBUG_SQL_FLOW', true);
+#}
+
+/**
+ * Allow the use of Proxy IPs when searching for client
+ * IP to be used
+ *
+ * This can be set to one of the following:
+ *   - false: to use only REMOTE_ADDR
+ *   - true: to use all allowed headers (not advised)
+ *   - array of one or more the following:
+ *		'X-Forwarded-For',
+ *		'X-Client-IP',
+ *		'X-Real-IP',
+ *		'X-ProxyUser-Ip',
+ *		'CF-Connecting-IP',
+ *		'True-Client-IP',
+ *		'HTTP_X_FORWARDED',
+ *		'HTTP_X_FORWARDED_FOR',
+ *		'HTTP_X_CLUSTER_CLIENT_IP',
+ *		'HTTP_FORWARDED_FOR',
+ *		'HTTP_FORWARDED',
+ *		'HTTP_CLIENT_IP',
+ *
+ * NOTE: The following will always be checked:
+ *		'REMOTE_ADDR',
+ */
+$proxy_headers = null;
