@@ -1,4 +1,3 @@
-
 <?php
 /*
  +-------------------------------------------------------------------------+
@@ -801,9 +800,9 @@ function graph_edit() {
 				</div>
 				<script type='text/javascript'>
 				$(function() {
-					var width = $(window).width() - $('.cactiConsoleNavigationArea').width();
+					var rrdwidth = $(window).width() - $('.cactiConsoleNavigationArea').width();
 					$('#agg_preview').show();
-					$('#rrdtoolinfo, #imagewindow').css('max-width', width);
+					$('#rrdtoolinfo, #imagewindow').css('max-width', rrdwidth);
 				});
 				</script>
 			</td></tr>
@@ -1227,7 +1226,7 @@ function aggregate_items() {
 		$sql_where .= ($sql_where != '' ? ' AND ':'WHERE ') . ' agi.local_graph_id IN(' . get_request_var('local_graph_ids') . ')';
 	}
 
-	$total_rows = db_fetch_cell("SELECT COUNT(DISTINCT gl.id) AS total
+	$sql = "SELECT COUNT(DISTINCT gl.id) AS total
 		FROM graph_templates_graph AS gtg
 		INNER JOIN graph_local AS gl
 		ON gtg.local_graph_id=gl.id
@@ -1236,7 +1235,9 @@ function aggregate_items() {
 			FROM aggregate_graphs_items
 			WHERE aggregate_graph_id=$aggregate_id) AS agi
 		ON gtg.local_graph_id=agi.local_graph_id
-		$sql_where");
+		$sql_where";
+
+	$total_rows = get_total_row_data($_SESSION['sess_user_id'], $sql, array(), 'aggregate_graph');
 
 	$sql_order = get_order_string();
 	$sql_limit = ' LIMIT ' . ($rows*(get_request_var('page')-1)) . ',' . $rows;
@@ -1255,7 +1256,6 @@ function aggregate_items() {
 		$sql_order
 		$sql_limit");
 
-
 	?>
 	<script type='text/javascript'>
 	var totalItems=<?php print $total_items;?>;
@@ -1280,10 +1280,6 @@ function aggregate_items() {
 			$('#agg_preview').show();
 		}
 
-		$('#refresh').click(function() {
-			applyFilter();
-		});
-
 		$('#clear').click(function() {
 			clearFilter();
 		});
@@ -1292,7 +1288,7 @@ function aggregate_items() {
 			applyFilter();
 		});
 
-		$('#form_graphs').submit(function(event) {
+		$('#forms').submit(function(event) {
 			event.preventDefault();
 			applyFilter();
 		});
@@ -1305,7 +1301,7 @@ function aggregate_items() {
 	?>
 	<tr class='even'>
 		<td>
-			<form id='form_graphs' action='aggregate_graphs.php'>
+			<form id='forms' action='aggregate_graphs.php'>
 			<table class='filterTable'>
 				<tr>
 					<td>
@@ -1337,7 +1333,7 @@ function aggregate_items() {
 					</td>
 					<td>
 						<span>
-							<input type='button' class='ui-button ui-corner-all ui-widget' id='refresh' value='<?php print __esc('Go');?>' title='<?php print __esc('Set/Refresh Filters');?>'>
+							<input type='submit' class='ui-button ui-corner-all ui-widget' id='go' value='<?php print __esc('Go');?>' title='<?php print __esc('Set/Refresh Filters');?>'>
 							<input type='button' class='ui-button ui-corner-all ui-widget' id='clear' onClick='clearFilter()' value='<?php print __esc('Clear');?>' title='<?php print __esc('Clear Filters');?>'>
 						</span>
 					</td>
@@ -1561,19 +1557,11 @@ function aggregate_graph() {
 			$('#agg_preview').show();
 		}
 
-		$('#refresh').click(function() {
-			applyFilter();
-		});
-
 		$('#clear').click(function() {
 			clearFilter();
 		});
 
-		$('#filter').change(function() {
-			applyFilter();
-		});
-
-		$('#form_graphs').submit(function(event) {
+		$('#forms').submit(function(event) {
 			event.preventDefault();
 			applyFilter();
 		});
@@ -1587,7 +1575,7 @@ function aggregate_graph() {
 	?>
 	<tr class='even'>
 		<td>
-			<form id='form_graphs' action='aggregate_graphs.php'>
+			<form id='forms' action='aggregate_graphs.php'>
 			<table class='filterTable'>
 				<tr>
 					<td>
@@ -1635,7 +1623,7 @@ function aggregate_graph() {
 					</td>
 					<td>
 						<span>
-							<input type='button' class='ui-button ui-corner-all ui-widget' id='refresh' value='<?php print __esc('Go');?>' title='<?php print __esc('Set/Refresh Filters');?>'>
+							<input type='submit' class='ui-button ui-corner-all ui-widget' id='go' value='<?php print __esc('Go');?>' title='<?php print __esc('Set/Refresh Filters');?>'>
 							<input type='button' class='ui-button ui-corner-all ui-widget' id='clear' value='<?php print __esc('Clear');?>' title='<?php print __esc('Clear Filters');?>'>
 						</span>
 					</td>
@@ -1663,7 +1651,7 @@ function aggregate_graph() {
 		$sql_where .= ' AND ag.aggregate_template_id=' . get_request_var('template_id');
 	}
 
-	$total_rows = db_fetch_cell("SELECT COUNT(DISTINCT gl.id) AS total
+	$sql = "SELECT COUNT(DISTINCT gl.id) AS total
 		FROM graph_templates_graph AS gtg
 		INNER JOIN graph_local AS gl
 		ON gtg.local_graph_id=gl.id
@@ -1671,7 +1659,9 @@ function aggregate_graph() {
 		ON gtg.local_graph_id=ag.local_graph_id
 		LEFT JOIN aggregate_graph_templates AS agt
 		ON agt.id=ag.aggregate_template_id
-		$sql_where");
+		$sql_where";
+
+	$total_rows = get_total_row_data($_SESSION['sess_user_id'], $sql, array(), 'aggregate_graph');
 
 	$sql_order = get_order_string();
 	$sql_limit = ' LIMIT ' . ($rows*(get_request_var('page')-1)) . ',' . $rows;
