@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2021 The Cacti Group                                 |
+ | Copyright (C) 2004-2022 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -149,6 +149,10 @@ function api_auth_clear_user_setting($name) {
 
 	$user = $_SESSION['sess_user_id'];
 
+	if (read_config_option('client_timezone_support') == '0') {
+		unset($settings_user['client_timezone_support']);
+	}
+
 	if (!empty($user)) {
 		if (isset_request_var('tab') && get_nfilter_request_var('tab') == 'general') {
 			db_execute_prepared('DELETE FROM settings_user
@@ -455,6 +459,7 @@ function settings_javascript() {
 	var currentTab   = '<?php print get_nfilter_request_var('tab');?>';
 	var currentTheme = '<?php print get_selected_theme();?>';
 	var currentLang  = '<?php print read_config_option('user_language');?>';
+	var authMethod   = '<?php print read_config_option('auth_method');?>';
 
 	function clearUserSettings() {
 		$.get('auth_profile.php?action=clear_user_settings', function() {
@@ -563,6 +568,10 @@ function settings_javascript() {
 			});
 		});
 
+		if (authMethod == 2) {
+			$('#row_logout_everywhere').hide();
+		}
+
 		$('#auth_profile_edit2 .formData, #auth_profile_noreturn2 .formData').each(function() {
 			if ($(this).find('select, input[type!="button"]').length) {
 				$(this).parent().hover(
