@@ -95,6 +95,9 @@ if (isset($config['cacti_version'])) {
 	exit;
 }
 
+/* Should we allow proxy ip headers? */
+$config['proxy_headers'] = (isset($proxy_headers) ? $proxy_headers : null);
+
 /* Set the poller_id */
 if (isset($poller_id)) {
 	$config['poller_id'] = $poller_id;
@@ -269,8 +272,14 @@ if ((isset($no_http_headers) && $no_http_headers == true) || in_array($filename,
 	$config['is_web'] = false;
 }
 
+$auto_start = ini_get('session.auto_start');
+if ($config['is_web'] && ($auto_start == 'On' || $auto_start == '1')) {
+	print 'FATAL: PHP settings session.auto_start NOT supported.  Disable in your php.ini file and then restart your Web Service' . PHP_EOL;
+	exit;
+}
+
 /* set poller mode */
-global $local_db_cnn_id, $remote_db_cnn_id;
+global $local_db_cnn_id, $remote_db_cnn_id, $conn_mode;
 
 $config['connection'] = 'online';
 
@@ -296,8 +305,13 @@ if ($config['poller_id'] > 1 || isset($rdatabase_hostname)) {
 	/* gather the existing cactidb version */
 	$config['cacti_db_version'] = db_fetch_cell('SELECT cacti FROM version LIMIT 1', false, $local_db_cnn_id);
 
-	// We are a remote poller also try to connect to the remote database
-	$remote_db_cnn_id = db_connect_real($rdatabase_hostname, $rdatabase_username, $rdatabase_password, $rdatabase_default, $rdatabase_type, $rdatabase_port, $database_retries, $rdatabase_ssl, $rdatabase_ssl_key, $rdatabase_ssl_cert, $rdatabase_ssl_ca);
+	/**
+	 * If we have not been forced offline by the $conn_mode global and since we are
+	 * a remote poller, let's attempt to get back online.
+	 */
+	if ($conn_mode != 'offline') {
+		$remote_db_cnn_id = db_connect_real($rdatabase_hostname, $rdatabase_username, $rdatabase_password, $rdatabase_default, $rdatabase_type, $rdatabase_port, $database_retries, $rdatabase_ssl, $rdatabase_ssl_key, $rdatabase_ssl_cert, $rdatabase_ssl_ca);
+	}
 
 	if ($config['is_web'] && is_object($remote_db_cnn_id) &&
 		$config['connection'] != 'recovery' &&
@@ -372,12 +386,6 @@ if ($config['poller_id'] > 1) {
 	}
 }
 
-if (isset($cacti_db_session) && $cacti_db_session && db_table_exists('sessions')) {
-	include(dirname(__FILE__) . '/session.php');
-} else {
-	$cacti_db_session = false;
-}
-
 if (!defined('IN_CACTI_INSTALL')) {
 	set_error_handler('CactiErrorHandler');
 	register_shutdown_function('CactiShutdownHandler');
@@ -427,6 +435,12 @@ if ($config['is_web']) {
 	$config['cookie_options']     = $options;
 	$config['cacti_session_name'] = $cacti_session_name;
 
+	if (isset($cacti_db_session) && $cacti_db_session && db_table_exists('sessions') && $config['connection'] == 'online') {
+		include(dirname(__FILE__) . '/session.php');
+	} else {
+		$cacti_db_session = false;
+	}
+
 	/* we don't want these pages cached */
 	header('Last-Modified: ' . gmdate('D, d M Y H:i:s') . ' GMT');
 	header('X-Frame-Options: SAMEORIGIN');
@@ -528,6 +542,44 @@ include_once($config['library_path'] . '/api_automation.php');
 include_once($config['include_path'] . '/csrf.php');
 
 if ($config['is_web']) {
+	/* raise a message and perform a page refresh if we've changed modes */
+	if ($config['poller_id'] > 1) {
+		if (isset($_SESSION['connection_mode'])) {
+			$previous_mode = $_SESSION['connection_mode'];
+			$reload        = false;
+
+			cacti_log('Connection: ' . $config['connection'] . ', Previous Mode: ' . $previous_mode . ', Page: ' . $_SERVER['SCRIPT_NAME'], false, 'WEBUI', POLLER_VERBOSITY_DEBUG);
+
+			if ($config['connection'] == 'online' && ($config['connection'] != $previous_mode)) {
+				$reload  = true;
+				$message = __('The Main Data Collector has returned to an Online Status');
+				$level   = MESSAGE_LEVEL_INFO;
+			} else if ($config['connection'] != 'online' && $previous_mode == 'online') {
+				$reload  = true;
+				$message = __('The Main Data Collector has gone to an Offline or Recovering Status');
+				$level   = MESSAGE_LEVEL_ERROR;
+			}
+
+			if ($reload) {
+				$_SESSION['connection_mode'] = $config['connection'];
+
+				raise_message('connection_state', $message, $level);
+
+				session_destroy();
+
+				print '<div style="display:none">cactiRemoteState</div>';
+
+				exit;
+			}
+		} else {
+			cacti_log('Connection: ' . $config['connection'] . ', Previous Mode: notset', false, 'WEBUI', POLLER_VERBOSITY_DEBUG);
+
+			$previous_mode = $config['connection'];
+
+			$_SESSION['connection_mode'] = $config['connection'];
+		}
+	}
+
 	if (isset_request_var('newtheme')) {
 		unset($_SESSION['selected_theme']);
 	}
@@ -560,5 +612,5 @@ if ($config['is_web']) {
 api_plugin_hook('config_insert');
 
 /* set config cacti_version for plugins */
-$config['cacti_version'] = CACTI_VERSION;;
+$config['cacti_version'] = CACTI_VERSION;
 
