@@ -135,6 +135,7 @@ $cacti_version_codes = array(
 	'1.2.20'  => '0103',
 	'1.2.21'  => '0103',
 	'1.2.22'  => '0103',
+	'1.2.23'  => '0103',
 );
 
 $messages = array(
@@ -458,6 +459,25 @@ $cdef_functions = array(1 =>
 	'ROLL'
 );
 
+$phperrors = array (
+	E_ERROR => 'ERROR',
+	E_WARNING => 'WARNING',
+	E_PARSE => 'PARSE',
+	E_NOTICE => 'NOTICE',
+	E_CORE_ERROR => 'CORE_ERROR',
+	E_CORE_WARNING => 'CORE_WARNING',
+	E_COMPILE_ERROR  => 'COMPILE_ERROR',
+	E_COMPILE_WARNING => 'COMPILE_WARNING',
+	E_USER_ERROR => 'USER_ERROR',
+	E_USER_WARNING => 'USER_WARNING',
+	E_USER_NOTICE  => 'USER_NOTICE',
+	E_STRICT => 'STRICT',
+	E_RECOVERABLE_ERROR  => 'RECOVERABLE_ERROR',
+	E_DEPRECATED => 'DEPRECATED',
+	E_USER_DEPRECATED  => 'USER_DEPRECATED',
+	E_ALL => 'ALL'
+);
+
 if (cacti_version_compare(get_rrdtool_version(), '1.8.0', '>=')) {
 	$cdef_functions[] = 'ROUND';
 }
@@ -678,7 +698,7 @@ $poller_options = array(
 	2 => 'spine'
 );
 
-if (!file_exists(read_config_option('path_spine')) || !is_executable(read_config_option('path_spine'))) {
+if (read_config_option('path_spine') != '' && (!file_exists(read_config_option('path_spine')) || !is_executable(read_config_option('path_spine')))) {
 	unset($poller_options[2]);
 }
 
@@ -731,6 +751,7 @@ $heartbeats = array(
 	330    => __('%0.1f Minutes', 5.5),
 	600    => __('%d Minutes', 10),
 	660    => __('%d Minutes', 11),
+	900    => __('%d Minutes', 15),
 	1200   => __('%d Minutes', 20),
 	1800   => __('%d Minutes', 30),
 	2400   => __('%d Minutes', 40),
@@ -984,6 +1005,7 @@ if ($config['poller_id'] == 1 || $config['connection'] == 'online') {
 			),
 		__('Import/Export') => array(
 			'templates_import.php' => __('Import Templates'),
+			'package_import.php'   => __('Import Packages'),
 			'templates_export.php' => __('Export Templates')
 			),
 		__('Configuration')  => array(
@@ -1033,6 +1055,30 @@ $menu_glyphs = array(
 	__('Troubleshooting') => 'fa fa-bug'
 );
 
+$device_classes = array(
+	'wireless'     => __('Access Points, Controllers'),
+	'application'  => __('Application Related'),
+	'cacti'        => __('Cacti Related'),
+	'database'     => __('Database Related'),
+	'facilities'   => __('Facilities Related'),
+	'general'      => __('Generic Device'),
+	'hpc'          => __('HPC/Grid Computing'),
+	'hypervisor'   => __('Hypervisor Related'),
+	'remotemgmt'   => __('ILO, IPMI, iDrac, etc.'),
+	'license'      => __('Licensing Related'),
+	'linux'        => __('Linux Related'),
+	'loadbalancer' => __('Load Balancer'),
+	'switch'       => __('Network Switch'),
+	'router'       => __('Network Router'),
+	'firewall'     => __('Network Firewall'),
+	'storage'      => __('Storage Related'),
+	'telephony'    => __('Telco Related'),
+	'webserver'    => __('Web Server Related'),
+	'windows'      => __('Windows Related'),
+	'ups'          => __('UPS Related'),
+	'unassigned'   => __('Unassigned')
+);
+
 if ((isset($_SESSION['sess_user_id']))) {
 	if (db_table_exists('external_links')) {
 		$consoles = db_fetch_assoc('SELECT id, title, extendedstyle
@@ -1222,11 +1268,13 @@ $user_auth_realm_filenames = array(
 	'step_json.php' => 26,
 	'managers.php' => 15,
 	'rrdcleaner.php' => 15,
+	'rrdcheck.php' => 15,
 	'settings.php' => 15,
 	'links.php' => 15,
 	'data_queries.php' => 13,
 	'templates_export.php' => 16,
 	'templates_import.php' => 17,
+	'package_import.php' => 17,
 	'tree.php' => 4,
 	'user_admin.php' => 1,
 	'user_domains.php' => 1,
@@ -1481,6 +1529,13 @@ $dsstats_hourly_avg = array(
 	'360' => __('%d Hours', 6)
 );
 
+$rrdcheck_intervals = array(
+	'boost' => __('After Boost'),
+	'60'  => __('1 Hour'),
+	'240' => __('%d Hours', 4),
+	'1440' => __('%d Hours', 24)
+);
+
 $boost_max_rows_per_select = array(
 	'2000'   => __('2,000 Data Source Items'),
 	'5000'   => __('5,000 Data Source Items'),
@@ -1914,27 +1969,9 @@ $i18n_themes = array(
 $database_statuses = array(
 	0 => __('[Fail]'),
 	1 => __('[Warning]'),
-	2 => __('[Success]'),
-	3 => __('[Skipped]'),
-);
-
-$phperrors = array (
-	E_ERROR => 'ERROR',
-	E_WARNING => 'WARNING',
-	E_PARSE => 'PARSE',
-	E_NOTICE => 'NOTICE',
-	E_CORE_ERROR => 'CORE_ERROR',
-	E_CORE_WARNING => 'CORE_WARNING',
-	E_COMPILE_ERROR  => 'COMPILE_ERROR',
-	E_COMPILE_WARNING => 'COMPILE_WARNING',
-	E_USER_ERROR => 'USER_ERROR',
-	E_USER_WARNING => 'USER_WARNING',
-	E_USER_NOTICE  => 'USER_NOTICE',
-	E_STRICT => 'STRICT',
-	E_RECOVERABLE_ERROR  => 'RECOVERABLE_ERROR',
-	E_DEPRECATED => 'DEPRECATED',
-	E_USER_DEPRECATED  => 'USER_DEPRECATED',
-	E_ALL => 'ALL'
+	2 => __('[Restart]'),
+	3 => __('[Success]'),
+	4 => __('[Skipped]'),
 );
 
 $navigation = array(
@@ -2384,6 +2421,12 @@ $navigation = array(
 		'url' => 'rrdcleaner.php?action=restart',
 		'level' => '2'
 	),
+	'rrdcheck.php:' => array(
+		'title' => __('RRD Check'),
+		'mapping' => 'index.php:,utilities.php:',
+		'url' => 'rrdcheck.php',
+		'level' => '2'
+	),
 	'utilities.php:' => array(
 		'title' => __('Utilities'),
 		'mapping' => 'index.php:',
@@ -2588,6 +2631,12 @@ $navigation = array(
 		'url' => 'templates_import.php',
 		'level' => '1'
 	),
+	'package_import.php:' => array(
+		'title' => __('Import Packages'),
+		'mapping' => 'index.php:',
+		'url' => 'package_import.php',
+		'level' => '1'
+	),
 	'reports_admin.php:' => array(
 		'title' => __('Reporting'),
 		'mapping' => '',
@@ -2855,4 +2904,20 @@ if ($config['cacti_server_os'] == 'unix') {
 	);
 }
 
+$allowed_proxy_headers =	array(
+	'X-Forwarded-For',
+	'X-Client-IP',
+	'X-Real-IP',
+	'X-ProxyUser-Ip',
+	'CF-Connecting-IP',
+	'True-Client-IP',
+	'HTTP_X_FORWARDED',
+	'HTTP_X_FORWARDED_FOR',
+	'HTTP_X_CLUSTER_CLIENT_IP',
+	'HTTP_FORWARDED_FOR',
+	'HTTP_FORWARDED',
+	'HTTP_CLIENT_IP',
+	'REMOTE_ADDR',
+);
+
 api_plugin_hook('config_arrays');
