@@ -1,3 +1,26 @@
+/*
+  +-------------------------------------------------------------------------+
+  | Copyright (C) 2004-2022 The Cacti Group                                 |
+  |                                                                         |
+  | This program is free software; you can redistribute it and/or           |
+  | modify it under the terms of the GNU General Public License             |
+  | as published by the Free Software Foundation; either version 2          |
+  | of the License, or (at your option) any later version.                  |
+  |                                                                         |
+  | This program is distributed in the hope that it will be useful,         |
+  | but WITHOUT ANY WARRANTY; without even the implied warranty of          |
+  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
+  | GNU General Public License for more details.                            |
+  +-------------------------------------------------------------------------+
+  | Cacti: The Complete RRDTool-based Graphing Solution                     |
+  +-------------------------------------------------------------------------+
+  | This code is designed, written, and maintained by the Cacti Group. See  |
+  | about.php and/or the AUTHORS file for specific developer information.   |
+  +-------------------------------------------------------------------------+
+  | http://www.cacti.net/                                                   |
+  +-------------------------------------------------------------------------+
+*/
+
 // Host Autocomplete Magic
 var pageName = basename($(location).attr('pathname'));
 
@@ -251,7 +274,7 @@ function setMenuVisibility() {
 		}
 	});
 
-	// Functon to give life to the Navigation pane
+	// Function to give life to the Navigation pane
 	$('#nav li:has(ul) a.active').unbind().click(function(event) {
 		event.preventDefault();
 
