@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -22,7 +22,6 @@
  +-------------------------------------------------------------------------+
 */
 
-function upgrade_to_1_2_1() {
-	db_install_execute("UPDATE host SET deleted='' WHERE deleted IS NULL");
-	db_install_execute("ALTER TABLE host MODIFY COLUMN deleted char(3) NOT NULL default ''");
+function upgrade_to_1_0_4() {
+	db_install_add_key('poller_output_boost', 'KEY', 'PRIMARY', array('local_data_id', 'time', 'rrd_name'), 'BTREE');
 }
