@@ -38,12 +38,13 @@
  * @param  (string) String that points to the client ssl cert file
  * @param  (string) String that points to the ssl ca file
  *
- * @returns (bool) '1' for success, false for error
+ * @returns (bool|object) connection object on success, false for error
  */
 function db_connect_real($device, $user, $pass, $db_name, $db_type = 'mysql', $port = '3306', $retries = 20,
 	$db_ssl = false, $db_ssl_key = '', $db_ssl_cert = '', $db_ssl_ca = '', $persist = false) {
 
-	global $database_sessions, $database_total_queries, $database_persist, $config;
+	global $database_sessions, $database_details, $database_total_queries, $database_persist, $config;
+
 	$database_total_queries = 0;
 
 	$i = 0;
@@ -94,6 +95,10 @@ function db_connect_real($device, $user, $pass, $db_name, $db_type = 'mysql', $p
 		}
 	}
 
+	/* set connection timout for down servers */
+	$flags[PDO::ATTR_TIMEOUT] = 2;
+	$flage[PDO::ATTR_ERRMODE] = PDO::ERRMODE_EXCEPTION;
+
 	while ($i <= $retries) {
 		try {
 			if (strpos($device, '/') !== false && filetype($device) == 'socket') {
@@ -115,6 +120,24 @@ function db_connect_real($device, $user, $pass, $db_name, $db_type = 'mysql', $p
 
 			$database_sessions["$odevice:$port:$db_name"] = $cnn_id;
 
+			$object_hash = spl_object_hash($cnn_id);
+
+			$database_details[$object_hash] = array(
+				'database_conn'     => $cnn_id,
+				'database_hostname' => $device,
+				'database_username' => $user,
+				'database_password' => $pass,
+				'database_default'  => $db_name,
+				'database_type'     => $db_type,
+				'database_port'     => $port,
+				'database_retries'  => $retries,
+				'database_ssl'      => $db_ssl,
+				'database_ssl_key'  => $db_ssl_key,
+				'database_ssl_cert' => $db_ssl_cert,
+				'database_ssl_ca'   => $db_ssl_ca,
+				'database_persist'  => $persist,
+			);
+
 			$ver = db_get_global_variable('version', $cnn_id);
 
 			if (strpos($ver, 'MariaDB') !== false) {
@@ -199,6 +222,66 @@ function db_connect_real($device, $user, $pass, $db_name, $db_type = 'mysql', $p
 	return false;
 }
 
+function db_check_reconnect($db_conn = false) {
+	global $config, $database_details;
+
+	include($config['base_path'] . '/include/config.php');
+
+	if (cacti_sizeof($database_details) && $db_conn !== false) {
+		foreach($database_details as $det) {
+			if (spl_object_hash($det['database_conn']) == spl_object_hash($db_conn)) {
+				$database_hostname = $det['database_hostname'];
+				$database_username = $det['database_username'];
+				$database_password = $det['database_password'];
+				$database_default  = $det['database_default'];
+				$database_type     = $det['database_type'];
+				$database_port     = $det['database_port'];
+				$database_retries  = $det['database_retries'];
+				$database_ssl      = $det['database_ssl'];
+				$database_ssl_key  = $det['database_ssl_key'];
+				$database_ssl_cert = $det['database_ssl_cert'];
+				$database_ssl_ca   = $det['database_ssl_ca'];
+
+				break;
+			}
+		}
+	} else {
+		if (!isset($database_ssl))      $database_ssl      = false;
+		if (!isset($database_ssl_key))  $database_ssl_key  = '';
+		if (!isset($database_ssl_cert)) $database_ssl_cert = '';
+		if (!isset($database_ssl_ca))   $database_ssl_ca   = '';
+		if (!isset($database_retries))  $database_retries  = 2;
+		if (!isset($database_port))     $database_port     = 3306;
+	}
+
+	if ($db_conn !== false) {
+		$version = db_fetch_cell('SELECT 1', '', false, $db_conn);
+	} else {
+		$version = db_fetch_cell('SELECT 1');
+	}
+
+	if ($version === false) {
+		syslog(LOG_ALERT, 'CACTI: Database Connection went away.  Attempting to reconnect!');
+
+		db_close();
+
+		// Connect to the database server
+		db_connect_real(
+			$database_hostname,
+			$database_username,
+			$database_password,
+			$database_default,
+			$database_type,
+			$database_port,
+			$database_retries,
+			$database_ssl,
+			$database_ssl_key,
+			$database_ssl_cert,
+			$database_ssl_ca
+		);
+	}
+}
+
 function db_warning_handler($errno, $errstr, $errfile, $errline, $errcontext = []) {
 	throw new Exception($errstr, $errno);
 }
@@ -287,7 +370,8 @@ function db_execute($sql, $log = true, $db_conn = false) {
  * @return (bool) '1' for success, false for failed
  */
 function db_execute_prepared($sql, $params = array(), $log = true, $db_conn = false, $execute_name = 'Exec', $default_value = true, $return_func = 'no_return_function', $return_params = array()) {
-	global $database_sessions, $database_default, $config, $database_hostname, $database_port, $database_total_queries, $database_last_error, $database_log;
+	global $database_sessions, $database_default, $config, $database_hostname, $database_port, $database_total_queries, $database_last_error, $database_log, $affected_rows;
+
 	$database_total_queries++;
 
 	if (!isset($database_log)) {
@@ -313,7 +397,8 @@ function db_execute_prepared($sql, $params = array(), $log = true, $db_conn = fa
 	}
 
 	$errors = 0;
-	$db_conn->affected_rows = 0;
+
+	$affected_rows[spl_object_hash($db_conn)] = 0;
 
 	while (true) {
 		$query = $db_conn->prepare($sql);
@@ -358,8 +443,7 @@ function db_execute_prepared($sql, $params = array(), $log = true, $db_conn = fa
 		}
 
 		if ($en == '') {
-			// With PDO, we have to free this up
-			$db_conn->affected_rows = $query->rowCount();
+			$affected_rows[spl_object_hash($db_conn)] = $query->rowCount();
 
 			$return_value = $default_value;
 			if (function_exists($return_func)) {
@@ -404,7 +488,7 @@ function db_execute_prepared($sql, $params = array(), $log = true, $db_conn = fa
 
 						continue;
 					}
-				} else if ($en == 1153) {
+				} elseif ($en == 1153) {
 					if (strlen($sql) > 1024) {
 						$sql = substr($sql, 0, 1024) . '...';
 					}
@@ -663,7 +747,7 @@ function db_fetch_insert_id($db_conn = false) {
  *                         or false on error
  */
 function db_affected_rows($db_conn = false) {
-	global $database_sessions, $database_default, $database_hostname, $database_port;
+	global $database_sessions, $database_default, $database_hostname, $database_port, $affected_rows;
 
 	/* check for a connection being passed, if not use legacy behavior */
 	if (!is_object($db_conn)) {
@@ -674,7 +758,7 @@ function db_affected_rows($db_conn = false) {
 		}
 	}
 
-	return $db_conn->affected_rows;
+	return $affected_rows[spl_object_hash($db_conn)];
 }
 
 /**
@@ -1849,7 +1933,7 @@ function db_check_password_length() {
 
 	if ($len === false) {
 		die(__('Failed to determine password field length, can not continue as may corrupt password'));
-	} else if ($len < 80) {
+	} elseif ($len < 80) {
 		/* Ensure that the password length is increased before we start updating it */
 		db_execute("ALTER TABLE user_auth MODIFY COLUMN password varchar(256) NOT NULL default ''");
 
@@ -1988,15 +2072,15 @@ function db_dump_data($database = '', $tables = '', $credentials = array(), $out
 			if (strstr($name, '--') !== false) {      //name like --host
 				if($name == '--password') {
 					$password = $value;
-				} else if ($name == '--user') {
+				} elseif ($name == '--user') {
 					$username = $value;
 				} else {
 					$credentials_string .= $name . '=' . $value . ' ';
 				}
-			} else if(strstr($name, '-') !== false) { //name like -h
+			} elseif(strstr($name, '-') !== false) { //name like -h
 				if($name == '-p') {
 					$password = $value;
-				} else if ($name == '-u') {
+				} elseif ($name == '-u') {
 					$username = $value;
 				} else {
 					$credentials_string .= $name . $value . ' ';
@@ -2004,7 +2088,7 @@ function db_dump_data($database = '', $tables = '', $credentials = array(), $out
 			} else {                                  //name like host
 				if($name == 'password') {
 					$password = $value;
-				} else if ($name == 'user') {
+				} elseif ($name == 'user') {
 					$username = $value;
 				} else {
 					$credentials_string .= '--' . $name . '=' . $value . ' ';
