@@ -290,19 +290,19 @@ function cacti_stats_calc($array, $ptile = 95) {
 		$variance += pow(abs($number - $average), 2);
 	}
 
-	$ptile_index = floor($elements * (1 - ($ptile/100)));
-	$p95n_index  = floor($elements * 0.05);
-	$p90n_index  = floor($elements * 0.1);
-	$p75n_index  = floor($elements * 0.25);
-	$p50n_index  = floor($elements * 0.50);
-	$p25n_index  = floor($elements * 0.75);
+	$ptile_index = ceil($elements * (1 - ($ptile/100)));
+	$p95n_index  = ceil($elements * 0.05);
+	$p90n_index  = ceil($elements * 0.1);
+	$p75n_index  = ceil($elements * 0.25);
+	$p50n_index  = ceil($elements * 0.50);
+	$p25n_index  = ceil($elements * 0.75);
 
 	$results = array(
-		'p95n'     => $array[$p95n_index],
-		'p90n'     => $array[$p90n_index],
-		'p75n'     => $array[$p75n_index],
-		'p50n'     => $array[$p50n_index],
-		'p25n'     => $array[$p25n_index],
+		'p95n'     => (isset($array[$p95n_index]) ? $array[$p95n_index] : 0),
+		'p90n'     => (isset($array[$p90n_index]) ? $array[$p90n_index] : 0),
+		'p75n'     => (isset($array[$p75n_index]) ? $array[$p75n_index] : 0),
+		'p50n'     => (isset($array[$p50n_index]) ? $array[$p50n_index] : 0),
+		'p25n'     => (isset($array[$p25n_index]) ? $array[$p25n_index] : 0),
 		'average'  => $average,
 		'sum'      => $sum,
 		'elements' => $elements,
