@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2021 The Cacti Group                                 |
+ | Copyright (C) 2004-2022 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -26,6 +26,7 @@ class Net_Ping
 {
 	var $socket;
 	var $host;
+	var $port;
 	var $ping_status;
 	var $ping_response;
 	var $snmp_status;
@@ -73,7 +74,7 @@ class Net_Ping
 		$this->request_len = strlen($this->request);
 	}
 
-	function ping_error_handler($errno, $errmsg, $filename, $linenum, $vars) {
+	function ping_error_handler($errno, $errmsg, $filename, $linenum, $vars = []) {
 		return true;
 	}
 
@@ -310,7 +311,7 @@ class Net_Ping
 
 		/* check result for uptime */
 		if ($output !== false && $output != 'U' && strlen($output)) {
-			/* calculte total time */
+			/* calculate total time */
 			$this->snmp_status   = $this->time*1000;
 			$this->snmp_response = 'Device responded to SNMP';
 
@@ -422,10 +423,10 @@ class Net_Ping
 
 						/* get the end time after the packet was received */
 						$this->time = $this->get_time($this->precision);
-							
+
 						$errno = socket_last_error($this->socket);
 						socket_clear_error($this->socket);
-						if (($code == -1 || empty($code)) && 
+						if (($code == -1 || empty($code)) &&
 							($errno == EHOSTUNREACH || $errno == ECONNRESET || $errno == ECONNREFUSED)) {
 
 							/* set the return message */
@@ -491,7 +492,7 @@ class Net_Ping
 				}
 			}
 
-			/* initilize the socket */
+			/* initialize the socket */
 			if (strpos($host_ip, ':') !== false) {
 				if (defined('AF_INET6')) {
 					if (version_compare(PHP_VERSION, '5.5.4', '<')) {
@@ -530,11 +531,11 @@ class Net_Ping
 					$this->ping_response = __('TCP ping: socket_connect(), reason: %s', socket_strerror($errno));
 					$this->ping_status   = 'down';
 
+					socket_clear_error($this->socket);
+
 					$this->close_socket();
 					$this->restore_cacti_error_handler();
 
-					socket_clear_error($this->socket);
-
 					return false;
 				}
 
