@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2021 The Cacti Group                                 |
+ | Copyright (C) 2004-2022 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -73,13 +73,16 @@ function api_plugin_hook($name) {
 
 	if (!empty($result)) {
 		foreach ($result as $hdata) {
-			if (!in_array($hdata['name'], $plugins_integrated)) {
+			if (!in_array($hdata['name'], $plugins_integrated, true)) {
 				if (file_exists($config['base_path'] . '/plugins/' . $hdata['name'] . '/' . $hdata['file'])) {
 					include_once($config['base_path'] . '/plugins/' . $hdata['name'] . '/' . $hdata['file']);
 				}
+
 				$function = $hdata['function'];
 				if (function_exists($function)) {
 					api_plugin_run_plugin_hook($name, $hdata['name'], $function, $args);
+				} else {
+					cacti_log(sprintf('WARNING: Function does not exist %s with function %s' . PHP_EOL, $name, $hdata['function']), false, 'PLUGIN', POLLER_VERBOSITY_MEDIUM);
 				}
 			}
 		}
@@ -96,6 +99,7 @@ function api_plugin_hook_function($name, $parm = NULL) {
 	static $hook_cache = array();
 
 	$ret = $parm;
+
 	if (defined('IN_CACTI_INSTALL') || !db_table_exists('plugin_hooks')) {
 		return $ret;
 	}
@@ -118,16 +122,37 @@ function api_plugin_hook_function($name, $parm = NULL) {
 		$result = $hook_cache[$name];
 	}
 
+	if (empty($ret)) {
+		$null_ret = true;
+	} else {
+		$null_ret = false;
+	}
+
 	if (!empty($result)) {
 		foreach ($result as $hdata) {
 			if (!in_array($hdata['name'], $plugins_integrated)) {
 				$p[] = $hdata['name'];
+
 				if (file_exists($config['base_path'] . '/plugins/' . $hdata['name'] . '/' . $hdata['file'])) {
 					include_once($config['base_path'] . '/plugins/' . $hdata['name'] . '/' . $hdata['file']);
 				}
+
 				$function = $hdata['function'];
+
 				if (function_exists($function)) {
+					if (is_array($ret)) {
+						$is_array = true;
+					} else {
+						$is_array = false;
+					}
+
 					$ret = api_plugin_run_plugin_hook_function($name, $hdata['name'], $function, $ret);
+
+					if (($is_array && !is_array($ret)) || ($ret == null && $null_ret === false)) {
+						if (cacti_sizeof($result) > 1) {
+							cacti_log(sprintf("WARNING: Plugin hook '%s' from Plugin '%s' must return the calling array or variable, and it is not doing so.  Please report this to the Plugin author.", $function, $hdata['name']), false, 'PLUGIN');
+						}
+					}
 				}
 			}
 		}
@@ -147,14 +172,12 @@ function api_plugin_run_plugin_hook($hook, $plugin, $function, $args) {
 
 		$required_capabilities = array(
 			// Poller related
-			'poller_top'               => array('remote_collect'), // Poller Top
-			'poller_bottom'            => array('remote_collect'), // Poller execution, api_plugin_hook
-			'update_host_status'       => array('remote_collect'), // Processing poller output, api_plugin_hook
-			'poller_output'            => array('remote_collect'), // Poller output activities
-			'poller_command_args'      => array('remote_collect'), // Command line arguments
-			'cacti_stats_update'       => array('remote_collect'), // Updating statistics
-			'poller_finishing'         => array('remote_collect'), // Poller post processing
-			'poller_exiting'           => array('remote_collect'), // Poller exception handling
+			'poller_top'               => array('remote_collect'),              // Poller Top, api_plugin_hook
+			'poller_bottom'            => array('remote_poller'),               // Poller execution, api_plugin_hook
+			'update_host_status'       => array('remote_collect'),              // Processing poller output, api_plugin_hook
+			'poller_output'            => array('remote_collect'),              // Poller output activities
+			'poller_finishing'         => array('remote_collect'),              // Poller post processing, api_plugin_hook
+			'poller_exiting'           => array('remote_collect'),              // Poller exception handling, api_plugin_hook
 
 			// GUI Related
 			'page_head'                => array('online_view', 'offline_view'), // Navigation, api_plugin_hook
@@ -170,19 +193,28 @@ function api_plugin_run_plugin_hook($hook, $plugin, $function, $args) {
 		if ($plugin_capabilities === false) {
 			$function($args);
 		} elseif (api_plugin_hook_is_remote_collect($hook, $plugin, $required_capabilities)) {
-			if (api_plugin_status_run($hook, $required_capabilities, $plugin_capabilities)) {
+			if (api_plugin_status_run($hook, $required_capabilities, $plugin_capabilities, $plugin)) {
 				$function($args);
 			}
 		} elseif (isset($required_capabilities[$hook])) {
-			if (api_plugin_status_run($hook, $required_capabilities, $plugin_capabilities)) {
+			if (api_plugin_status_run($hook, $required_capabilities, $plugin_capabilities, $plugin)) {
 				$function($args);
 			}
-		} else {
+		} elseif ($config['connection'] == 'online' ||
+			((api_plugin_has_capability($plugin, 'offline_mgmt') || api_plugin_has_capability($plugin, 'offline_view'))
+			&& $config['connection'] != 'online')) {
 			$function($args);
+		} else {
+			// Don't run as they are not required
 		}
 
 		// See if we need to restore the menu to original
-		if (($hook == 'config_arrays' || 'config_insert') && $config['connection'] == 'offline') {
+		$remote_hooks = array(
+			'config_arrays',
+			'config_insert',
+		);
+
+		if (in_array($hook, $remote_hooks) && ($config['connection'] == 'offline' || $config['connection'] == 'recovery')) {
 			if (!api_plugin_has_capability($plugin, 'offline_mgmt')) {
 				if ($orig_menu !== $menu) {
 					$menu = $orig_menu;
@@ -202,7 +234,8 @@ function api_plugin_run_plugin_hook_function($hook, $plugin, $function, $ret) {
 	if ($config['poller_id'] > 1) {
 		$required_capabilities = array(
 			// Poller related
-			'poller_output'            => array('remote_collect'), // Processing poller output, api_plugin_hook_function
+			'poller_output'            => array('remote_collect'),              // Processing poller output, api_plugin_hook_function
+			'cacti_stats_update'       => array('remote_collect'),              // Updating Cacti stats
 
 			// GUI Related
 			'top_header'               => array('online_view', 'offline_view'), // Top Tabs, api_plugin_hook_function
@@ -217,17 +250,17 @@ function api_plugin_run_plugin_hook_function($hook, $plugin, $function, $ret) {
 
 		$plugin_capabilities = api_plugin_remote_capabilities($plugin);
 
-		// we will run if capabilities are not set
 		if ($plugin_capabilities === false) {
+			// we will run if capabilities are not set
 			$ret = $function($ret);
-		// run if hooks is remote_collect and we support it
 		} elseif (api_plugin_hook_is_remote_collect($hook, $plugin, $required_capabilities)) {
-			if (api_plugin_status_run($hook, $required_capabilities, $plugin_capabilities)) {
+			// run if hook is remote_collect and we support it
+			if (api_plugin_status_run($hook, $required_capabilities, $plugin_capabilities, $plugin)) {
 				$ret = $function($ret);
 			}
-		// run if hooks is remote_collect and we support it
 		} elseif (isset($required_capabilities[$hook])) {
-			if (api_plugin_status_run($hook, $required_capabilities, $plugin_capabilities)) {
+			// run if hook is remote_collect and we support it
+			if (api_plugin_status_run($hook, $required_capabilities, $plugin_capabilities, $plugin)) {
 				$ret = $function($ret);
 			}
 		} else {
@@ -350,17 +383,33 @@ function api_plugin_has_capability($plugin, $capability) {
 	}
 }
 
-function api_plugin_status_run($hook, $required_capabilities, $plugin_capabilities) {
+function api_plugin_status_run($hook, $required_capabilities, $plugin_capabilities, $plugin = '') {
 	global $config;
 
 	$status = $config['connection'];
 
+	if ($plugin == '') {
+		cacti_log('WARNING: The function \'api_plugin_status_run\' API has changed.  Please add the $plugin attribute to the last position', false, 'PLUGIN');
+		$plugin = 'Unknown';
+	}
+
+	// Don't run if not a supported hook
 	if (!isset($required_capabilities[$hook])) {
-		return true;
+		cacti_log(sprintf('WARNING: Not running hook %s for plugin %s as its not a supported Remote Hook', $hook, $plugin), false, 'PLUGIN');
+
+		return false;
 	}
 
 	foreach($required_capabilities[$hook] as $capability) {
-		if ($status == 'online' && strpos($capability, 'online') === false) {
+		if ($capability == 'remote_collect') {
+			if (strpos($plugin_capabilities, "$capability:1") !== false) {
+				return true;
+			}
+		} elseif ($capability == 'remote_poller') {
+			if (strpos($plugin_capabilities, "$capability:1") !== false) {
+				return true;
+			}
+		} elseif ($status == 'online' && strpos($capability, 'online') === false) {
 			continue;
 		} elseif (($status == 'offline' || $status == 'recovery') && strpos($capability, 'offline') === false) {
 			continue;
@@ -494,6 +543,12 @@ function api_plugin_db_table_create($plugin, $table, $data) {
 	}
 }
 
+function api_plugin_drop_table($table) {
+	db_execute("DROP TABLE IF EXISTS $table");
+
+	api_plugin_drop_remote_table($table);
+}
+
 function api_plugin_db_changes_remove($plugin) {
 	$tables = db_fetch_assoc_prepared("SELECT `table`
 		FROM plugin_db_changes
@@ -506,6 +561,8 @@ function api_plugin_db_changes_remove($plugin) {
 			db_execute('DROP TABLE IF EXISTS `' . $table['table'] . '`;');
 		}
 
+		api_plugin_drop_remote_table($table['table']);
+
 		db_execute_prepared("DELETE FROM plugin_db_changes
 			WHERE plugin = ?
 			AND method ='create'",
@@ -530,7 +587,7 @@ function api_plugin_db_changes_remove($plugin) {
 	}
 }
 
-function api_plugin_db_add_column ($plugin, $table, $column) {
+function api_plugin_db_add_column($plugin, $table, $column) {
 	global $config, $database_default;
 
 	// Example: api_plugin_db_add_column ('thold', 'plugin_config',
@@ -617,6 +674,7 @@ function api_plugin_install($plugin) {
 
 	if (!defined('IN_CACTI_INSTALL')) {
 		define('IN_CACTI_INSTALL', 1);
+		define('IN_PLUGIN_INSTALL', 1);
 	}
 
 	$dependencies = api_plugin_get_dependencies($plugin);
@@ -626,7 +684,7 @@ function api_plugin_install($plugin) {
 	if (!$proceed) {
 		$message .= '<br><br>' . __('Plugin cannot be installed.');
 
-		raise_message($message, MESSAGE_LEVEL_ERROR);
+		raise_message('dependency_check', $message, MESSAGE_LEVEL_ERROR);
 
 		header('Location: plugins.php?header=false');
 
@@ -688,6 +746,8 @@ function api_plugin_install($plugin) {
 				array($plugin));
 		}
 	}
+
+	api_plugin_replicate_config();
 }
 
 function api_plugin_uninstall_integrated() {
@@ -726,6 +786,8 @@ function api_plugin_uninstall($plugin, $tables = true) {
 			WHERE plugin = ?',
 			array($plugin));
 	}
+
+	api_plugin_replicate_config();
 }
 
 function api_plugin_check_config($plugin) {
@@ -762,15 +824,25 @@ function api_plugin_enable($plugin) {
 }
 
 function api_plugin_is_enabled($plugin) {
+	static $pstatus = array();;
+
+	if (isset($pstatus[$plugin])) {
+		return $pstatus[$plugin];
+	}
+
 	$status = db_fetch_cell_prepared('SELECT status
 		FROM plugin_config
 		WHERE directory = ?',
 		array($plugin), false);
 
 	if ($status == '1') {
+		$pstatus[$plugin] = true;
+
 		return true;
 	}
 
+	$pstatus[$plugin] = false;
+
 	return false;
 }
 
@@ -781,6 +853,62 @@ function api_plugin_disable($plugin) {
 		SET status = 4
 		WHERE directory = ?',
 		array($plugin));
+
+	api_plugin_replicate_config();
+}
+
+function api_plugin_replicate_config() {
+	global $config;
+
+	include_once($config['base_path'] . '/lib/poller.php');
+
+	$gone_time = read_config_option('poller_interval') * 2;
+
+	$pollers = array_rekey(
+		db_fetch_assoc('SELECT
+			id,
+			UNIX_TIMESTAMP() - UNIX_TIMESTAMP(last_status) AS last_polled
+			FROM poller
+			WHERE id > 1
+			AND disabled=""'),
+		'id', 'last_polled'
+	);
+
+	if (cacti_sizeof($pollers)) {
+		foreach($pollers as $poller_id => $last_polled) {
+			if ($last_polled < $gone_time) {
+				replicate_out($poller_id, 'plugins');
+			}
+		}
+	}
+}
+
+function api_plugin_drop_remote_table($table) {
+	global $config;
+
+	include_once($config['base_path'] . '/lib/poller.php');
+
+	$gone_time = read_config_option('poller_interval') * 2;
+
+	$pollers = array_rekey(
+		db_fetch_assoc('SELECT
+			id,
+			UNIX_TIMESTAMP() - UNIX_TIMESTAMP(last_status) AS last_polled
+			FROM poller
+			WHERE id > 1
+			AND disabled=""'),
+		'id', 'last_polled'
+	);
+
+	if (cacti_sizeof($pollers)) {
+		foreach($pollers as $poller_id => $last_polled) {
+			$rcnn_id = poller_connect_to_remote($poller_id);
+
+			if ($rcnn_id !== false) {
+				db_execute("DROP TABLE IF EXISTS $table", false, $rcnn_id);
+			}
+		}
+	}
 }
 
 function api_plugin_disable_all($plugin) {
@@ -790,6 +918,8 @@ function api_plugin_disable_all($plugin) {
 		SET status = 4
 		WHERE directory = ?',
 		array($plugin));
+
+	api_plugin_replicate_config();
 }
 
 function api_plugin_moveup($plugin) {
@@ -811,6 +941,8 @@ function api_plugin_moveup($plugin) {
 		db_execute_prepared('UPDATE plugin_config SET id = ? WHERE id = ?', array($prior_id, $id));
 		db_execute_prepared('UPDATE plugin_config SET id = ? WHERE id = ?', array($id, $temp_id));
 	}
+
+	api_plugin_replicate_config();
 }
 
 function api_plugin_movedown($plugin) {
@@ -822,6 +954,8 @@ function api_plugin_movedown($plugin) {
 	db_execute_prepared('UPDATE plugin_config SET id = ? WHERE id = ?', array($temp_id, $next_id));
 	db_execute_prepared('UPDATE plugin_config SET id = ? WHERE id = ?', array($next_id, $id));
 	db_execute_prepared('UPDATE plugin_config SET id = ? WHERE id = ?', array($id, $temp_id));
+
+	api_plugin_replicate_config();
 }
 
 function api_plugin_register_hook($plugin, $hook, $function, $file, $enable = false) {
@@ -872,12 +1006,16 @@ function api_plugin_register_hook($plugin, $hook, $function, $file, $enable = fa
 			AND `hook` = ?",
 			array($function, $status, $file, $plugin, $hook));
 	}
+
+	api_plugin_replicate_config();
 }
 
 function api_plugin_remove_hooks($plugin) {
 	db_execute_prepared('DELETE FROM plugin_hooks
 		WHERE name = ?',
 		array($plugin));
+
+	api_plugin_replicate_config();
 }
 
 function api_plugin_enable_hooks($plugin) {
@@ -885,16 +1023,20 @@ function api_plugin_enable_hooks($plugin) {
 		SET status = 1
 		WHERE name = ?',
 		array($plugin));
+
+	api_plugin_replicate_config();
 }
 
 function api_plugin_disable_hooks($plugin) {
 	db_execute_prepared("UPDATE plugin_hooks
-		SET status = 0
+		SET status = 4
 		WHERE name = ?
 		AND hook != 'config_settings'
 		AND hook != 'config_arrays'
 		AND hook != 'config_form'",
 		array($plugin));
+
+	api_plugin_replicate_config();
 }
 
 function api_plugin_disable_hooks_all($plugin) {
@@ -902,6 +1044,8 @@ function api_plugin_disable_hooks_all($plugin) {
 		SET status = 0
 		WHERE name = ?",
 		array($plugin));
+
+	api_plugin_replicate_config();
 }
 
 function api_plugin_register_realm($plugin, $file, $display, $admin = true) {
@@ -925,7 +1069,7 @@ function api_plugin_register_realm($plugin, $file, $display, $admin = true) {
 		$realm_id = $realm_ids[0]['id'];
 	} elseif (cacti_sizeof($realm_ids) > 1) {
 		$realm_id = $realm_ids[0]['id'];
-		cacti_log('WARNING: Registering Realm for Plugin ' . $plugin . ' and Filenames ' . $file . ' is ambiguous.  Using first matching Realm.  Contact the plugin owner to resolve this issue.');
+		cacti_log('WARNING: Registering Realm for Plugin ' . $plugin . ' and Filenames ' . $file . ' is ambiguous.  Using first matching Realm.  Contact the plugin owner to resolve this issue.', false, 'PLUGIN');
 
 		unset($realm_ids[0]);
 
@@ -1003,6 +1147,8 @@ function api_plugin_register_realm($plugin, $file, $display, $admin = true) {
 			WHERE id = ?',
 			array($display, $file, $realm_id));
 	}
+
+	api_plugin_replicate_config();
 }
 
 function api_plugin_remove_realms($plugin) {
@@ -1025,6 +1171,8 @@ function api_plugin_remove_realms($plugin) {
 	db_execute_prepared('DELETE FROM plugin_realms
 		WHERE plugin = ?',
 		array($plugin));
+
+	api_plugin_replicate_config();
 }
 
 function api_plugin_load_realms() {
