@@ -726,7 +726,7 @@ function format_snmp_string($string, $snmp_oid_included, $value_output_format =
 		$string = trim($string);
 	}
 
-	/* remove quotes and extranious data */
+	/* remove quotes and extraneous data */
 	$string = trim($string, " \n\r\v\"'");
 
 	/* return the easiest value */
@@ -906,7 +906,7 @@ function snmp_escape_string($string) {
 	}
 
 	if (substr_count($string, SNMP_ESCAPE_CHARACTER)) {
-		$string = substr_replace(SNMP_ESCAPE_CHARACTER, "\\" . SNMP_ESCAPE_CHARACTER, $string);
+		$string = str_replace(SNMP_ESCAPE_CHARACTER, "\\" . SNMP_ESCAPE_CHARACTER, $string);
 	}
 
 	return SNMP_ESCAPE_CHARACTER . $string . SNMP_ESCAPE_CHARACTER;
