@@ -35,6 +35,7 @@ require(__DIR__ . '/include/cli_check.php');
 require_once($config['base_path'] . '/lib/poller.php');
 require_once($config['base_path'] . '/lib/boost.php');
 require_once($config['base_path'] . '/lib/dsstats.php');
+require_once($config['base_path'] . '/lib/rrdcheck.php');
 require_once($config['base_path'] . '/lib/rrd.php');
 
 /* get the boost polling cycle */
@@ -153,6 +154,9 @@ if ($child == false) {
 
 		/* Launch the boost children */
 		if ($continue) {
+			/* Allow mysql to flush the rename transaction */
+			sleep(7);
+
 			boost_launch_children();
 
 			/* Wait for all processes to continue */
@@ -196,6 +200,7 @@ if ($child == false) {
 
 			if ($rrd_updates > 0) {
 				dsstats_boost_bottom();
+				rrdcheck_boost_bottom();
 
 				api_plugin_hook('boost_poller_bottom');
 			}
