@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2020 The Cacti Group                                 |
+ | Copyright (C) 2004-2022 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -298,7 +298,7 @@ function poll_for_data() {
 
 	$local_data_ids = get_nfilter_request_var('local_data_ids');
 	$host_id        = get_filter_request_var('host_id');
-	$poller_id      = get_nfilter_request_var('poller_id');
+	$poller_id      = get_filter_request_var('poller_id');
 	$return         = array();
 
 	$i = 0;
@@ -382,7 +382,7 @@ function poll_for_data() {
 						);
 
 						if (function_exists('proc_open')) {
-							$cactiphp = proc_open(read_config_option('path_php_binary') . ' -q ' . $config['base_path'] . '/script_server.php realtime ' . $poller_id, $cactides, $pipes);
+							$cactiphp = proc_open(read_config_option('path_php_binary') . ' -q ' . $config['base_path'] . '/script_server.php realtime ' . cacti_escapeshellarg($poller_id), $cactides, $pipes);
 							$output = fgets($pipes[1], 1024);
 							$using_proc_function = true;
 						} else {
@@ -443,8 +443,8 @@ function run_remote_data_query() {
 function run_remote_discovery() {
 	global $config;
 
-	$poller_id = $config['poller_id'];
-	$network   = get_filter_request_var('network');
+	$poller_id = cacti_escapeshellarg($config['poller_id']);
+	$network   = cacti_escapeshellarg(get_filter_request_var('network'));
 	$php       = cacti_escapeshellcmd(read_config_option('path_php_binary'));
 	$path      = cacti_escapeshellarg(read_config_option('path_webroot') . '/poller_automation.php');
 
