@@ -1,3 +1,4 @@
+#!/usr/bin/env php
 <?php
 /*
  +-------------------------------------------------------------------------+
@@ -28,34 +29,6 @@ if (function_exists('pcntl_async_signals')) {
 	declare(ticks = 100);
 }
 
-ini_set('output_buffering', 'Off');
-
-require(__DIR__ . '/include/cli_check.php');
-
-/* need to capture signals from users */
-function sig_handler($signo) {
-	global $include_file, $function, $parameters;
-
-	switch ($signo) {
-		case SIGTERM:
-		case SIGINT:
-		case SIGABRT:
-		case SIGQUIT:
-		case SIGSEGV:
-			cacti_log("WARNING: Script Server terminated with signal '$signo' in file:'" . basename($include_file) . "', function:'$function', params:'$parameters'", false, 'PHPSVR', POLLER_VERBOSITY_MEDIUM);
-			db_close();
-
-			exit;
-			break;
-		default:
-			cacti_log("WARNING: Script Server received signal '$signo' in file:'$include_file', function:'$function', params:'$parameters'", false, 'PHPSVR', POLLER_VERBOSITY_HIGH);
-
-			break;
-	}
-}
-
-/* used for includes */
-/* install signal handlers for UNIX only */
 $parent_pid = '';
 if (function_exists('posix_getppid')) {
 	$parent_pid = posix_getppid();
@@ -69,7 +42,7 @@ if (function_exists('pcntl_signal')) {
 	pcntl_signal(SIGSEGV, 'sig_handler');
 }
 
-error_reporting(E_ALL);
+error_reporting(0);
 
 /* define STDOUT/STDIN file descriptors if not running under CLI */
 if (php_sapi_name() != 'cli') {
@@ -79,17 +52,103 @@ if (php_sapi_name() != 'cli') {
 
 /* make sure data is flushed immediately */
 ob_implicit_flush();
+ini_set('output_buffering', 'Off');
 
-/* signal for realtime */
-global $environ, $poller_id;
+global $environ, $poller_id, $connection;
+
+/* some debugging */
+$pid         = getmypid();
+$ctr         = 0;
+$poller_id   = 1;
+$environ     = 'cmd';
+$conn_mode   = 'online';
+$legacy      = true;
+$options     = array();
+$help        = false;
+$version     = false;
+
+$called_by_script_server = false;
+
+$shortopts = 'VvHh';
+
+$longopts = array(
+	'environ::',
+	'poller::',
+	'mode::',
+	'version',
+	'help'
+);
+
+$options = getopt($shortopts, $longopts);
+
+if (sizeof($options)) {
+	foreach($options as $arg => $value) {
+		$allow_multi = false;
+
+		switch($arg) {
+			case 'enviorn':
+				$environ = $value;
+
+				break;
+			case 'poller':
+				$poller_id = $value;
+
+				break;
+			case 'mode':
+				$conn_mode = $value;
+
+				break;
+			case 'help':
+				$help = true;
+
+				break;
+			case 'version':
+				$version = true;
+
+				break;
+		}
+	}
+} elseif ($_SERVER['argc'] >= 2) {
+	if (in_array('spine', $_SERVER['argv'])) {
+		$environ = 'spine';
+	} elseif (in_array('realtime', $_SERVER['argv'])) {
+		$environ = 'realtime';
+	} elseif (in_array('cmd', $_SERVER['argv']) || in_array('cmd.php', $_SERVER['argv'])) {
+		$environ = 'cmd';
+	} else {
+		$environ = 'other';
+	}
+
+	if ($_SERVER['argc'] == 3) {
+		$poller_id = $_SERVER['argv'][2];
+	} else {
+		$poller_id = 1;
+	}
+}
+
+require(__DIR__ . '/include/cli_check.php');
+
+if ($help) {
+	display_help();
+	exit(0);
+} elseif ($version) {
+	display_version();
+	exit(0);
+}
 
 /* record the script start time */
 $start = microtime(true);
 
-/* some debugging */
-$pid = getmypid();
-$ctr = 0;
-$called_by_script_server = false;
+if ($config['cacti_server_os'] == 'win32') {
+	cacti_log('DEBUG: GETCWD: ' . strtolower(strtr(getcwd(),"\\",'/')), false, 'PHPSVR', POLLER_VERBOSITY_DEBUG);
+	cacti_log('DEBUG: DIRNAM: ' . strtolower(strtr(dirname(__FILE__),"\\",'/')), false, 'PHPSVR', POLLER_VERBOSITY_DEBUG);
+} else {
+	cacti_log('DEBUG: GETCWD: ' . strtr(getcwd(),"\\",'/'), false, 'PHPSVR', POLLER_VERBOSITY_DEBUG);
+	cacti_log('DEBUG: DIRNAM: ' . strtr(dirname(__FILE__),"\\",'/'), false, 'PHPSVR', POLLER_VERBOSITY_DEBUG);
+}
+
+cacti_log('DEBUG: SERVER: ' . $environ . ' PARENT: ' . $parent_pid, false, 'PHPSVR', POLLER_VERBOSITY_DEBUG);
+cacti_log('DEBUG: FILENM: ' . __FILE__, false, 'PHPSVR', POLLER_VERBOSITY_DEBUG);
 
 /* if multiple polling intervals are defined, compensate for them */
 $polling_interval = read_config_option('poller_interval');
@@ -103,44 +162,6 @@ if (!empty($polling_interval)) {
 /* Let PHP only run 1 second longer than the max runtime */
 ini_set('max_execution_time', MAX_POLLER_RUNTIME + 1);
 
-/* Record the calling environment */
-if ($_SERVER['argc'] >= 2) {
-	if (substr( $_SERVER['argv'][1], 0, 5) == 'spine')
-		global $force_level;
-		$environ = 'spine';
-		if (strlen($_SERVER['argv'][1]) > 5) {
-			$force_level = intval(substr($_SERVER['argv'][1], 5));
-			cacti_log('INFO: Forcing log level to: ' . $force_level, false, 'PHPSVR', POLLER_VERBOSITY_HIGH);
-		}
-	else
-		if (($_SERVER['argv'][1] == 'cmd.php') || ($_SERVER['argv'][1] == 'cmd'))
-			$environ = 'cmd';
-		elseif ($_SERVER['argv'][1] == 'realtime')
-			$environ = 'realtime';
-		else
-			$environ = 'other';
-
-	if ($_SERVER['argc'] == 3)
-		$poller_id = $_SERVER['argv'][2];
-	else
-		$poller_id = 1;
-} else {
-	$environ = 'cmd';
-	$poller_id = 1;
-}
-
-cacti_log('DEBUG: SERVER: ' . $environ . ' PARENT: ' . $parent_pid, false, 'PHPSVR', POLLER_VERBOSITY_DEBUG);
-
-if ($config['cacti_server_os'] == 'win32') {
-	cacti_log('DEBUG: GETCWD: ' . strtolower(strtr(getcwd(),"\\",'/')), false, 'PHPSVR', POLLER_VERBOSITY_DEBUG);
-	cacti_log('DEBUG: DIRNAM: ' . strtolower(strtr(dirname(__FILE__),"\\",'/')), false, 'PHPSVR', POLLER_VERBOSITY_DEBUG);
-} else {
-	cacti_log('DEBUG: GETCWD: ' . strtr(getcwd(),"\\",'/'), false, 'PHPSVR', POLLER_VERBOSITY_DEBUG);
-	cacti_log('DEBUG: DIRNAM: ' . strtr(dirname(__FILE__),"\\",'/'), false, 'PHPSVR', POLLER_VERBOSITY_DEBUG);
-}
-
-cacti_log('DEBUG: FILENM: ' . __FILE__, false, 'PHPSVR', POLLER_VERBOSITY_DEBUG);
-
 /* send status back to the server */
 cacti_log('PHP Script Server has Started - Parent is ' . $environ, false, 'PHPSVR', POLLER_VERBOSITY_HIGH);
 
@@ -238,26 +259,34 @@ while (1) {
 			/* validate the existence of the function, and include if applicable */
 			if (!function_exists($function)) {
 				if (file_exists($include_file)) {
-					/* quirk in php on Windows, believe it or not.... */
-					/* path must be lower case */
+					/**
+					 * quirk in php on Windows, believe it or not....
+					 * path must be lower case
+					 */
 					if ($config['cacti_server_os'] == 'win32') {
 						$include_file = strtolower($include_file);
 					}
 
-					/* set this variable so the calling script can determine if it was called
-					 * by the script server or stand-alone */
+					/**
+					 * set this variable so the calling script can determine if it was called
+					 * by the script server or stand-alone
+					 */
 					$called_by_script_server = true;
 
 					/* turn on output buffering to avoid problems with nasty scripts */
 					ob_start();
 					include_once($include_file);
 					ob_end_clean();
+
+					error_reporting(0);
 				} else {
 					cacti_log('WARNING: PHP Script File to be included, does not exist', false, 'PHPSVR');
 				}
 			}
 
 			if (function_exists($function)) {
+				error_reporting(0);
+
 				if ($parameters == '') {
 					$result = call_user_func($function);
 				} else {
@@ -394,3 +423,71 @@ function parseArgs($string, &$str_list, $debug = false) {
 
 	return $parse_ok;
 }
+
+/**
+ * sig_handler - properly handle signals and shutdown
+ */
+function sig_handler($signo) {
+	global $include_file, $function, $parameters;
+
+	switch ($signo) {
+		case SIGTERM:
+		case SIGINT:
+		case SIGABRT:
+		case SIGQUIT:
+		case SIGSEGV:
+			cacti_log("WARNING: Script Server terminated with signal '$signo' in file:'" . basename($include_file) . "', function:'$function', params:'$parameters'", false, 'PHPSVR', POLLER_VERBOSITY_MEDIUM);
+			db_close();
+
+			exit;
+			break;
+		default:
+			cacti_log("WARNING: Script Server received signal '$signo' in file:'$include_file', function:'$function', params:'$parameters'", false, 'PHPSVR', POLLER_VERBOSITY_HIGH);
+
+			break;
+	}
+}
+
+/**
+ * display_version - displays version information
+ *
+ * @return (void)
+ */
+function display_version() {
+	$version = get_cacti_version();
+	print "Cacti Script Server, Version $version " . COPYRIGHT_YEARS . PHP_EOL;
+}
+
+/**
+ * display_help - displays help information
+ *
+ * @return (void)
+ */
+function display_help () {
+	display_version();
+
+	print PHP_EOL;
+	print 'usage: script_server.php [environ poller_id] | [ --environ=S --poller=N --mode [--force-level=N] ]' . PHP_EOL . PHP_EOL;
+	print 'Cacti\'s Script Server.  The Script Server provides a memory resident server for executing php' . PHP_EOL;
+	print 'scripts saving reducing the time to process the scripts through pre-compiling them for all consumers.' . PHP_EOL;
+	print 'The Script Server can be called using two methods.  The first method is the legacy method.  When using' . PHP_EOL;
+	print 'the legacy method, the first argument will be the environment, and the second will be the poller id.' . PHP_EOL . PHP_EOL;
+
+	print 'The modern calling method has multiple options processed by getopt.  Those options include:' . PHP_EOL . PHP_EOL;
+
+	print '  --environ=S      The default being \'cmd\', and options being \'spine\', \'cmd\', and \'realtime\'' . PHP_EOL;
+	print '  --poller=N       The poller id for the Data Collector in use' . PHP_EOL;
+	print '  --force-level=N  Force the logging at the level specified.' . PHP_EOL;
+	print '  --mode=S         Force a Database mode \'online\' or \'offline\'.  This is only relevant for' . PHP_EOL;
+	print '                   Remote Data Collectors.' . PHP_EOL . PHP_EOL;
+
+	print 'If no options are passed to the Script Server, it assumes that the environ is \'cmd\' and the poller id' . PHP_EOL;
+	print 'is 1 or the Main Data Collector.' . PHP_EOL . PHP_EOL;
+
+	print 'It is common that when developing Cacti Data Input methods one will use the Script Server to test' . PHP_EOL;
+	print 'scripts prior to creating thousands of Graphs using them.  To to that simply create at least' . PHP_EOL;
+	print 'one Data Source, start the Script Server, and then copy the Poller Cache entry into a running' . PHP_EOL;
+	print 'Script Server.  When doing so you should see the output you expect printed to standard output.  When' . PHP_EOL;
+	print 'running the Script Server, simply enter \'quit\' to exit.' . PHP_EOL . PHP_EOL;
+}
+
