@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2020 The Cacti Group                                 |
+ | Copyright (C) 2004-2022 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -327,7 +327,7 @@ function vdef_item_remove_confirm() {
 	<tr>
 		<td class='topBoxAlt'>
 			<p><?php print __('Click \'Continue\' to delete the following VDEF\'s.'); ?></p>
-			<p><?php print __('VDEF Name: %s', html_escape($vdef['name']));?><br>
+			<p><?php print __esc('VDEF Name: %s', $vdef['name']);?><br>
 			<em><?php $vdef_item_type = $vdef_item['type']; print $vdef_item_types[$vdef_item_type];?></em>: <strong><?php print html_escape(get_vdef_item_name($vdef_item['id']));?></strong></p>
 		</td>
 	</tr>
@@ -335,6 +335,8 @@ function vdef_item_remove_confirm() {
 		<td class='right'>
 			<input type='button' class='ui-button ui-corner-all ui-widget' id='cancel' value='<?php print __esc('Cancel');?>' onClick='$("#cdialog").dialog("close");' name='cancel'>
 			<input type='button' class='ui-button ui-corner-all ui-widget' id='continue' value='<?php print __esc('Continue');?>' name='continue' title='<?php print __esc('Remove VDEF Item');?>'>
+			<input type='hidden' id='my_vdef_id' value='<?php print $vdef['id'];?>'>
+			<input type='hidden' id='my_id' value='<?php print $vdef_item['id'];?>'>
 		</td>
 	</tr>
 	<?php
@@ -342,23 +344,6 @@ function vdef_item_remove_confirm() {
 	html_end_box();
 
 	form_end();
-
-	?>
-	<script type='text/javascript'>
-	$(function() {
-		$('#continue').click(function(data) {
-			$.post('vdef.php?action=item_remove', {
-				__csrf_magic: csrfMagicToken,
-				vdef_id: <?php print get_request_var('vdef_id');?>,
-				id: <?php print get_request_var('id');?>
-			}, function(data) {
-				$('#cdialog').dialog('close');
-				loadPageNoHeader('vdef.php?action=edit&header=false&id=<?php print get_request_var('id');?>');
-			});
-		});
-	});
-	</script>
-	<?php
 }
 
 function vdef_item_remove() {
@@ -366,7 +351,9 @@ function vdef_item_remove() {
 	get_filter_request_var('vdef_id');
 	/* ==================================================== */
 
-	db_execute_prepared('DELETE FROM vdef_items WHERE id = ?', array(get_request_var('vdef_id')));
+	db_execute_prepared('DELETE FROM vdef_items
+		WHERE id = ?',
+		array(get_request_var('id')));
 }
 
 function vdef_item_edit() {
@@ -654,7 +641,7 @@ function vdef_edit() {
 	$(function() {
 		$('#vdef_edit3').find('.cactiTable').attr('id', 'vdef_item');
 		$('.cdialog').remove();
-		$('body').append("<div class='cdialog' id='cdialog'></div>");
+		$('#main').append("<div class='cdialog' id='cdialog'></div>");
 
 		<?php if (read_config_option('drag_and_drop') == 'on') { ?>
 		$('#vdef_item').unbind().tableDnD({
@@ -672,8 +659,26 @@ function vdef_edit() {
 			$.get(request)
 				.done(function(data) {
 					$('#cdialog').html(data);
+
 					applySkin();
-					$('#cdialog').dialog({ title: '<?php print __esc('Delete VDEF Item');?>', minHeight: 80, minWidth: 500 });
+
+					$('#continue').off('click').on('click', function(data) {
+						$.post('vdef.php?action=item_remove', {
+							__csrf_magic: csrfMagicToken,
+							vdef_id: $('#my_vdef_id').val(),
+							id: $('#my_id').val()
+						}).done(function(data) {
+							$('#cdialog').dialog('close');
+							loadPageNoHeader('vdef.php?action=edit&header=false&id='+$('#my_vdef_id').val());
+						});
+					});
+
+					$('#cdialog').dialog({
+						title: '<?php print __esc('Delete VDEF Item');?>',
+						close: function () { $('.delete').blur(); $('.selectable').removeClass('selected'); },
+						minHeight: 80,
+						minWidth: 500
+					});
 				})
 				.fail(function(data) {
 					getPresentHTTPError(data);
